@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataHcsAgentHelmConfig(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-hcs.dataHcsAgentHelmConfig.DataHcsAgentHelmConfig",
 ):
@@ -30,23 +30,23 @@ class DataHcsAgentHelmConfig(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         aks_cluster_name: builtins.str,
         managed_application_name: builtins.str,
         resource_group_name: builtins.str,
         aks_resource_group: typing.Optional[builtins.str] = None,
-        expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", typing.Dict[str, typing.Any]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        timeouts: typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/hcs/d/agent_helm_config hcs_agent_helm_config} Data Source.
 
@@ -68,7 +68,7 @@ class DataHcsAgentHelmConfig(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHcsAgentHelmConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c4d9c4b5f5b5440743791e9e554e63d0258e9a5fdc37c6bb9385252dec371200)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataHcsAgentHelmConfigConfig(
@@ -148,8 +148,8 @@ class DataHcsAgentHelmConfig(
     @jsii.member(jsii_name="exposeGossipPortsInput")
     def expose_gossip_ports_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "exposeGossipPortsInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "exposeGossipPortsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -170,8 +170,8 @@ class DataHcsAgentHelmConfig(
     @jsii.member(jsii_name="timeoutsInput")
     def timeouts_input(
         self,
-    ) -> typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", cdktf.IResolvable]], jsii.get(self, "timeoutsInput"))
+    ) -> typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", _cdktf_9a9027ec.IResolvable]], jsii.get(self, "timeoutsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="aksClusterName")
@@ -181,7 +181,7 @@ class DataHcsAgentHelmConfig(
     @aks_cluster_name.setter
     def aks_cluster_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "aks_cluster_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c0943bcb6b20dbaf3274d7c69d4bfd612048c7ddbeab477ea6e6874f7c4ad800)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "aksClusterName", value)
 
@@ -193,22 +193,24 @@ class DataHcsAgentHelmConfig(
     @aks_resource_group.setter
     def aks_resource_group(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "aks_resource_group").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__084d3606b2c49207bbbdaa481b56db74ddfed2d9310e34be13499dcdae9d4f65)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "aksResourceGroup", value)
 
     @builtins.property
     @jsii.member(jsii_name="exposeGossipPorts")
-    def expose_gossip_ports(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "exposeGossipPorts"))
+    def expose_gossip_ports(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "exposeGossipPorts"))
 
     @expose_gossip_ports.setter
     def expose_gossip_ports(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "expose_gossip_ports").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0c1e86b99b5ab798081beaace0ac7edda57dc0bd9bf065c2d21e5ed0067bfe8e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "exposeGossipPorts", value)
 
@@ -220,7 +222,7 @@ class DataHcsAgentHelmConfig(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bc7b4c2d1ff9eaf4c293a0028112309eccf850cc5e7177b95907bc866eec20bb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -232,7 +234,7 @@ class DataHcsAgentHelmConfig(
     @managed_application_name.setter
     def managed_application_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "managed_application_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__60b780bd38f2160c07f03a86a265f728b23969acce7d2a34ab91c13f2fe46ada)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "managedApplicationName", value)
 
@@ -244,14 +246,14 @@ class DataHcsAgentHelmConfig(
     @resource_group_name.setter
     def resource_group_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfig, "resource_group_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b76a109d8ef3a4ae1b0a255478f3bd714bce381385842f59b759762d9d71f088)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceGroupName", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-hcs.dataHcsAgentHelmConfig.DataHcsAgentHelmConfigConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -269,24 +271,24 @@ class DataHcsAgentHelmConfig(
         "timeouts": "timeouts",
     },
 )
-class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
+class DataHcsAgentHelmConfigConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         aks_cluster_name: builtins.str,
         managed_application_name: builtins.str,
         resource_group_name: builtins.str,
         aks_resource_group: typing.Optional[builtins.str] = None,
-        expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        timeouts: typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", typing.Dict[str, typing.Any]]] = None,
+        timeouts: typing.Optional[typing.Union["DataHcsAgentHelmConfigTimeouts", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -305,11 +307,11 @@ class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
         :param timeouts: timeouts block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcs/d/agent_helm_config#timeouts DataHcsAgentHelmConfig#timeouts}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(timeouts, dict):
             timeouts = DataHcsAgentHelmConfigTimeouts(**timeouts)
         if __debug__:
-            type_hints = typing.get_type_hints(DataHcsAgentHelmConfigConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__386071b81fe90224564de50429e997464ad66eabe8214cdeea78f41581953ab9)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -324,7 +326,7 @@ class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument expose_gossip_ports", value=expose_gossip_ports, expected_type=type_hints["expose_gossip_ports"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument timeouts", value=timeouts, expected_type=type_hints["timeouts"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "aks_cluster_name": aks_cluster_name,
             "managed_application_name": managed_application_name,
             "resource_group_name": resource_group_name,
@@ -355,12 +357,12 @@ class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -371,46 +373,48 @@ class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def aks_cluster_name(self) -> builtins.str:
@@ -456,13 +460,13 @@ class DataHcsAgentHelmConfigConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def expose_gossip_ports(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Denotes that the gossip ports should be exposed. Defaults to ``false``.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcs/d/agent_helm_config#expose_gossip_ports DataHcsAgentHelmConfig#expose_gossip_ports}
         '''
         result = self._values.get("expose_gossip_ports")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -506,9 +510,9 @@ class DataHcsAgentHelmConfigTimeouts:
         :param default: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/hcs/d/agent_helm_config#default DataHcsAgentHelmConfig#default}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHcsAgentHelmConfigTimeouts.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__dce99136ec54c0e4bb9f792a7b65a267abaca3501d49144f19fbbacb451d309c)
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if default is not None:
             self._values["default"] = default
 
@@ -531,13 +535,13 @@ class DataHcsAgentHelmConfigTimeouts:
 
 
 class DataHcsAgentHelmConfigTimeoutsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-hcs.dataHcsAgentHelmConfig.DataHcsAgentHelmConfigTimeoutsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -545,7 +549,7 @@ class DataHcsAgentHelmConfigTimeoutsOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataHcsAgentHelmConfigTimeoutsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c12fbaf45705b624cead4ee1c9ba25f07d2ac88dce7ccc40b62b6c05310a067b)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -567,7 +571,7 @@ class DataHcsAgentHelmConfigTimeoutsOutputReference(
     @default.setter
     def default(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfigTimeoutsOutputReference, "default").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9de2aa4b0d39545dc00a81b0a1f7bf8f6e9e5a06b0c6dcf048f1195baa30d400)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "default", value)
 
@@ -575,16 +579,16 @@ class DataHcsAgentHelmConfigTimeoutsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataHcsAgentHelmConfigTimeoutsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__052c8fcec458a5466bbe9f0f6983c6499c2552620f2b0eacb170ab906acd955d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -597,3 +601,107 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c4d9c4b5f5b5440743791e9e554e63d0258e9a5fdc37c6bb9385252dec371200(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    aks_cluster_name: builtins.str,
+    managed_application_name: builtins.str,
+    resource_group_name: builtins.str,
+    aks_resource_group: typing.Optional[builtins.str] = None,
+    expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c0943bcb6b20dbaf3274d7c69d4bfd612048c7ddbeab477ea6e6874f7c4ad800(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__084d3606b2c49207bbbdaa481b56db74ddfed2d9310e34be13499dcdae9d4f65(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0c1e86b99b5ab798081beaace0ac7edda57dc0bd9bf065c2d21e5ed0067bfe8e(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bc7b4c2d1ff9eaf4c293a0028112309eccf850cc5e7177b95907bc866eec20bb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__60b780bd38f2160c07f03a86a265f728b23969acce7d2a34ab91c13f2fe46ada(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b76a109d8ef3a4ae1b0a255478f3bd714bce381385842f59b759762d9d71f088(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__386071b81fe90224564de50429e997464ad66eabe8214cdeea78f41581953ab9(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    aks_cluster_name: builtins.str,
+    managed_application_name: builtins.str,
+    resource_group_name: builtins.str,
+    aks_resource_group: typing.Optional[builtins.str] = None,
+    expose_gossip_ports: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    timeouts: typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dce99136ec54c0e4bb9f792a7b65a267abaca3501d49144f19fbbacb451d309c(
+    *,
+    default: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c12fbaf45705b624cead4ee1c9ba25f07d2ac88dce7ccc40b62b6c05310a067b(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9de2aa4b0d39545dc00a81b0a1f7bf8f6e9e5a06b0c6dcf048f1195baa30d400(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__052c8fcec458a5466bbe9f0f6983c6499c2552620f2b0eacb170ab906acd955d(
+    value: typing.Optional[typing.Union[DataHcsAgentHelmConfigTimeouts, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
